function [X, Y] = computesupport(F, kappa, signcontrast, rho, threshold, r_origins, nr_of_origins, Rmax)
%% SOURCESUPPORT: 
%  INPUT:   F - far field operator
%           kappa - wave number
%           rho - size of region of interest [-rho,rho]^2
%           threshold - eigenvalues with absolute values below threshold will be
%                       discarded 
%           r_origins - radius of the circle containing centers of the test
%                       circles
%           nr_of_origins - number of test circles
%           Rmax - size of plots
%  OUTPUT: X, Y - xy-data of the boundary of the convex source support of farfield
%  EXAMPLE USAGE: 


%% COMPUTE CONVEX HULL OF SCATTERER %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% compute origins for the test circles
theta_origins = (0:nr_of_origins-1)' * 2*pi/nr_of_origins;
c = cos(theta_origins); s = sin(theta_origins);
origins = r_origins * [c, s];  % origins of the test cirlces
clear r_origins theta_origins c s

radii = zeros(nr_of_origins, 1);  % initialize variable for radii of test circles

% compute parameterization for test cirles
np = 99;
theta = (0:np)' * 2*pi/np;
c = cos(theta); s = sin(theta);
xhatp = [c, s];  % measurement points
clear np theta c s

% initiate some variables to compute boundary of CSS
xhelp = linspace(-rho, rho, 200);
[X, Y] = meshgrid(xhelp, xhelp);

for iter = 1 : nr_of_origins  % loop over all origins of test circles
  
  % estimate radius of the support around shifted origin  
  radii(iter) = estimateradius(F, kappa, signcontrast, (origins(iter,:))', threshold, Rmax);
  
  xcirc = origins(iter,1) + radii(iter)*xhatp(:,1);
  ycirc = origins(iter,2) + radii(iter)*xhatp(:,2);
  
%  figure(50)
   plot(xcirc, ycirc, 'linewidth', 2)
   plot(origins(iter,1),origins(iter,2),'k+', 'markersize', 10, 'linewidth', 2)
  

  % check which point in [X,Y] are contained in current test circle
  in = inpolygon(X,Y,xcirc,ycirc);
  X = X(in);
  Y = Y(in);
  
%   axis([-20 20 -20 20])
%   axis square
%   set(gca,'Fontsize',20)
%   set(gca,'XTick',[-20,-10,0,10,20]);
%   set(gca,'YTick',[-20,-10,0,10,20]);
%   grid on
%   box on
%    
%   pause(0.1)
end

% figure(50)
% axis square
% grid on
% set(gca,'Fontsize',20)


%% compute boundary of CH %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
k = convhull(X, Y);
X = X(k);
Y = Y(k);
