function eigenvaluesTRFr(kappa, r, Nmax, threshold)
%% SHOW PLOT OF EIGENVALUES OF Fr+TR:
%  INPUT:
%  kappa - wave number
%  r - radius of scatterer
%  Nmax - number of eigenvalues that are computed
%  threshold - discard eigenvalues smaller than threshold

hankel = @(n,rho) besselh(n,rho);
eigOfFrho = @(n,kappa,rho) 8*pi*1i*besselj(n,kappa*rho)./hankel(n,kappa*rho);
eigOfTBrho = @(n,kappa,rho) 4*pi^2*rho*(besselj(n,kappa*rho)).^2;

lambda = 2*pi/kappa;  % wave length
Rmax = 10*r;  % max radius of test ball

n = 0:Nmax-1; 

% fprintf('\nWave length: %2.1f\n\n', lambda)
% fprintf('\nRadius of scatterer: %2.1f\n\n', r)

eigFr = eigOfFrho(n,kappa,r);

Rvec = 0:0.1*lambda:Rmax;
nvec = length(Rvec);
qvecTBRplusFrpos = zeros(nvec,1); qvecTBRplusFrneg = zeros(nvec,1);
qvecTBRpos = zeros(nvec,1); qvecTBRneg = zeros(nvec,1);
for iter = 1:nvec
    
    eigTBR = eigOfTBrho(n,kappa,Rvec(iter));
    eigTBRplusFr = eigTBR+eigFr;
    

    qvecTBRplusFrpos(iter) = sum(real(eigTBRplusFr)>threshold);
    qvecTBRpos(iter) = sum(real(eigTBR)>threshold);
    
    qvecTBRplusFrneg(iter) = sum(real(eigTBRplusFr)<-threshold);
    qvecTBRneg(iter) = sum(real(eigTBR)<-threshold);
        
end

qvecFrpos = sum(real(eigFr)>threshold) * ones(size(qvecTBRplusFrpos));
    
qvecFrneg = sum(real(eigFr)<-threshold) * ones(size(qvecTBRplusFrneg));

% plot of positive eigenvalues    
figure()
plot(Rvec,qvecTBRplusFrpos,'k-','linewidth',2)
hold on
plot(Rvec,qvecFrpos,'r:','linewidth',2)
plot(Rvec,qvecTBRpos,'b--','linewidth',2)
hold off
legend('#\{Re(\lambda_n^{(r)})+\mu_n^{(R)}\}>\delta','#\{Re(\lambda_n^{(r)})\}>\delta','#\{\mu_n^{(R)}\}>\delta','Location','NorthWest')
set(gca,'Fontsize',16)
xlabel('R')
title(['$k=',num2str(kappa),', r=',num2str(r),', \delta=',num2str(threshold),'$'],'Interpreter','latex')

% print(['plots/radiallysymmetric_int_kappa',num2str(kappa),'_r',num2str(r),'_delta',num2str(threshold),'.eps'],'-depsc');

% plot of negative eigenvalues
figure()
plot(Rvec,qvecTBRplusFrneg,'k-','linewidth',2)
hold on
plot(Rvec,qvecFrneg,'r:','linewidth',2)
plot(Rvec,qvecTBRneg,'b--','linewidth',2)
hold off
legend('#\{Re(\lambda_n^{(r)})+\mu_n^{(R)}\}<-\delta','#\{Re(\lambda_n^{(r)})\}<-\delta','#\{\mu_n^{(R)}\}<-\delta','Location','NorthEast')
set(gca,'Fontsize',16)
xlabel('R')
title(['$k=',num2str(kappa),', r=',num2str(r),', \delta=',num2str(threshold),'$'],'Interpreter','latex')

% print(['plots/radiallysymmetric_ext_kappa',num2str(kappa),'_r',num2str(r),'_delta',num2str(threshold),'.eps'],'-depsc');
