function [TB] = evaluateTB_circle(kappa,nobs,zB,rB)
%% evaluateTB: Evaluates the operator TB=H_B^*H_B of the monotonicity test
%
%  INPUT:   kappa - wave number
%           nobs - number of observation and receiver directions
%                  (equidistant on the unit sphere)
%           zB, rB - center and radius of test ball B
%
%  OUTPUT:  TB - operator TB (nobs times nobs)
%
%  EXAMPLE USAGE: [TB] = evaluateTB(1,32,[1;0],0.1)


%% Iteration over all incident directions
pin = 2*pi/nobs;
cs = cos((0:(nobs-1))*pin);
sn = sin((0:(nobs-1))*pin);

Uiatz = exp(1i*kappa*(cs*zB(1)+sn*zB(2)));  % incident field at zTest

TB = (Uiatz'*Uiatz);


thetaminusphi1 = repmat(cs',1,nobs) - repmat(cs,nobs,1);
thetaminusphi2 = repmat(sn',1,nobs) - repmat(sn,nobs,1);
normthetaminusphi = sqrt( thetaminusphi1.^2 + thetaminusphi2.^2 );

bla = rB * 2*pi*besselj(0,kappa*rB*normthetaminusphi);

TB = TB.*bla;


end

