function indefinite(kappa, nobs, example, signcontrast, r_origins, nr_of_origins, Rmax, noiselevel, threshold)
%% CONVEX HULL
%  INPUT:
%  kappa - wave number
%  nobs - number of incident/observation directions
%  example - scatterers that are used
%  signcontrast - 1: convex hull of Dirichlet obstacles, 
%                -1: convex hull of Neumann obstacles
%  r_origins - radius of the circle containing centers of the test
%              circles
%  nr_of_origins - number of test circles
%  Rmax - size of plots
%  noiselevel - relative noiselevel
%  threshold - eigenvalues with absolute values below threshold will be
%              discarded

%% 
subsampling = 1;  % increase the number of discretization points for the Nystrom method if nobs is too low

thresholdEigenvalues = max([threshold, 100*noiselevel]);  % don't use eigenvalues with absolute values smaller than this threshold

% fprintf('\nWave length: %2.1f\n\n', 2*pi/kappa)

% fprintf('\nParameters:\n')
% fprintf('Example: %s\n', example)
% fprintf('Wave number: kappa = %2.2f\n', kappa)
% fprintf('Wave length: lambda = %2.2f\n', 2*pi/kappa)
% fprintf('Number of incident/observation directions: nobs = %2i\n\n', nobs)
% 
% fprintf('Noise level: noiselevel = %1.2e\n\n', noiselevel)
% fprintf('Threshold in monotonicity test: delta = %1.2e\n\n', thresholdEigenvalues)


%% Evaluate Farfield
[F, Fcomponents, geometry] = computefarfield(example, kappa, subsampling*nobs, 0);
F = F(1:subsampling:end,1:subsampling:end);

% add noise to the data
if noiselevel > 0
    errmat = rand(size(F))-.5+1i*(rand(size(F))-.5);
    errmat = errmat ./ norm(errmat);
    F = F + errmat * noiselevel * norm(F);
    clear errmat
end

F = F * (2*pi/nobs);  % add quadrature weights of trapezoid rule to obtain matrix w.r.t. char. fnct. basis

% estimate error in the data
F = F * (2*pi/nobs);  % add quadrature weights of trapezoid rule to obtain matrix w.r.t. char. fnct. basis
EstNormalityError = norm(F*F'-F'*F);  % absoluter Datenfehler
% fprintf('Estimated normality error of F: %1.2e\n', EstNormalityError)


eigF = eig(F);

%% show geometry
figure()
nr_of_obstacles = size(geometry,2) / 2;
hold on
for iter = 1:nr_of_obstacles
    plot(geometry(:,2*iter-1), geometry(:,2*iter), '-', 'color', [0, 0, 1], 'linewidth', 2)
end
hold off
axis([-20 20 -20 20])
axis square
set(gca,'Fontsize',20)
set(gca,'XTick',[-20,-10,0,10,20]);
set(gca,'YTick',[-20,-10,0,10,20]);
grid on
box on

% print(['plots/geometry',example,'.eps'],'-depsc');


figure(50)
clf
nr_of_obstacles = size(geometry,2) / 2;
hold on
for iter = 1:nr_of_obstacles
    plot(geometry(:,2*iter-1), geometry(:,2*iter), '-', 'color', [0, 0, 1], 'linewidth', 2)
end
set(gca,'YDir','normal');
xlim([-Rmax Rmax]); ylim([-Rmax Rmax]);
axis square
set(gca,'Fontsize',28)
grid on

%%
[X,Y] = computesupport(F, kappa, signcontrast, 20, thresholdEigenvalues, r_origins, nr_of_origins, Rmax);

% show reconstruction
plot(X, Y, '-k', 'linewidth', 2)
axis([-20 20 -20 20])
axis square
set(gca,'Fontsize',20)
set(gca,'XTick',[-20,-10,0,10,20]);
set(gca,'YTick',[-20,-10,0,10,20]);
grid on
hold off
box on

% if signcontrast==1
%     print(['plots/reconstruction_Mixed_Dirichlet',example,'_kappa',num2str(kappa),'_nobs',num2str(nobs),'_err',num2str(noiselevel, '%2.0e'),'.eps'],'-depsc');
% elseif signcontrast==-1
%     print(['plots/reconstruction_Mixed__Neumann',example,'_kappa',num2str(kappa),'_nobs',num2str(nobs),'_err',num2str(noiselevel, '%2.0e'),'.eps'],'-depsc');
% end 
